﻿using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;
using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;

namespace XamGridProb
{
    public class zumMultiValueColumnBase : EditableColumn
    {


        public Boolean Enabled
        {
            get { return (Boolean)GetValue(EnabledProperty); }
            set { SetValue(EnabledProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Enabled.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty EnabledProperty =
            DependencyProperty.Register("Enabled", typeof(Boolean), typeof(zumMultiValueColumnBase), new PropertyMetadata(false, EnabledCallbac));

        private static void EnabledCallbac(DependencyObject dependencyObject, DependencyPropertyChangedEventArgs dependencyPropertyChangedEventArgs)
        {
            var control = dependencyObject as zumMultiValueColumnBase;
            if (control == null) return;

            control._provider.EnabledChanged();
        }


        private MultiValueColumnContentProvider _provider;

        public Object Value
        {
            get { return GetValue(ValueProperty); }
            set { SetValue(ValueProperty, value); }
        }


        public static readonly DependencyProperty ValueProperty =
            DependencyProperty.Register("Value", typeof(Object), typeof(zumMultiValueColumnBase), new PropertyMetadata(null));


        protected override ColumnContentProviderBase GenerateContentProvider()
        {

            return _provider ?? (_provider = new MultiValueColumnContentProvider());
        }
    }

    public class MultiValueColumnContentProvider : ColumnContentProviderBase
    {
        private TextBox _editor;
        private Boolean _isEnabled;
        private Boolean _isInitialized;

        public override FrameworkElement ResolveDisplayElement(Cell cell, Binding cellBinding)
        {
            if (cell != null)
            {
                var column = (cell.Column as zumMultiValueColumnBase);
                if (column != null && !_isInitialized)
                {
                    BindingOperations.SetBinding(column, zumMultiValueColumnBase.EnabledProperty, new Binding()
                        {
                            Path = new PropertyPath("Enable"),
                            Source = cell.Row.Data
                        });
                    _isInitialized = true;
                }
                _editor = new TextBox() { IsEnabled = _isEnabled };
                var selectedItemBinding = new Binding
                {
                    Source = cell.Row.Data,
                    Path = new PropertyPath(cell.Column.Key),

                };
                _editor.SetBinding(TextBox.TextProperty, selectedItemBinding);


            }
            return _editor;
        }

        protected override FrameworkElement ResolveEditorControl(Cell cell, object editorValue, double availableWidth, double availableHeight, Binding editorBinding)
        {
            var selectedItemBinding = new Binding
            {
                Source = cell.Row.Data,
                Path = new PropertyPath(cell.Column.Key),
                Mode = BindingMode.TwoWay,
                UpdateSourceTrigger = UpdateSourceTrigger.PropertyChanged
            };
            TextBox tb = new TextBox() { IsEnabled = _isEnabled };
            tb.SetBinding(TextBox.TextProperty, selectedItemBinding);
            return tb;
        }

        public override object ResolveValueFromEditor(Cell cell)
        {
            return cell.Value;
        }


        internal void EnabledChanged()
        {
           _editor.IsEnabled = _isEnabled = !_isEnabled;
        }
    }

}
